@@ -1,6 +1,6 @@
 # Copyright 2022- Python Language Server Contributors.
 
-from typing import Dict, List
+from typing import Any, Dict, List
 from unittest.mock import Mock
 
 import jedi
@@ -9,16 +9,29 @@ import pytest
 
 from pylsp import lsp, uris
 from pylsp.config.config import Config
-from pylsp.plugins.rope_autoimport import _get_score, _should_insert, get_names
+from pylsp.plugins.rope_autoimport import (
+    _get_score,
+    _should_insert,
+    get_name_or_module,
+    get_names,
+)
 from pylsp.plugins.rope_autoimport import (
     pylsp_completions as pylsp_autoimport_completions,
 )
 from pylsp.plugins.rope_autoimport import pylsp_initialize
 from pylsp.workspace import Workspace
 
+
 DOC_URI = uris.from_fs_path(__file__)
 
 
+def contains_autoimport(suggestion: Dict[str, Any], module: str) -> bool:
+    """Checks if `suggestion` contains an autoimport for `module`."""
+    return suggestion.get("label", "") == module and "import" in suggestion.get(
+        "detail", ""
+    )
+
+
 @pytest.fixture(scope="session")
 def autoimport_workspace(tmp_path_factory) -> Workspace:
     "Special autoimport workspace. Persists across sessions to make in-memory sqlite3 database fast."
@@ -26,7 +39,16 @@ def autoimport_workspace(tmp_path_factory) -> Workspace:
         uris.from_fs_path(str(tmp_path_factory.mktemp("pylsp"))), Mock()
     )
     workspace._config = Config(workspace.root_uri, {}, 0, {})
-    workspace._config.update({"rope_autoimport": {"memory": True, "enabled": True}})
+    workspace._config.update(
+        {
+            "rope_autoimport": {
+                "memory": True,
+                "enabled": True,
+                "completions": {"enabled": True},
+                "code_actions": {"enabled": True},
+            }
+        }
+    )
     pylsp_initialize(workspace._config, workspace)
     yield workspace
     workspace.close()
@@ -39,7 +61,9 @@ def completions(config: Config, autoimport_workspace: Workspace, request):
     com_position = {"line": 0, "character": position}
     autoimport_workspace.put_document(DOC_URI, source=document)
     doc = autoimport_workspace.get_document(DOC_URI)
-    yield pylsp_autoimport_completions(config, autoimport_workspace, doc, com_position)
+    yield pylsp_autoimport_completions(
+        config, autoimport_workspace, doc, com_position, None
+    )
     autoimport_workspace.rm_document(DOC_URI)
 
 
@@ -141,45 +165,13 @@ def test_autoimport_defined_name(config, workspace):
     com_position = {"line": 1, "character": 3}
     workspace.put_document(DOC_URI, source=document)
     doc = workspace.get_document(DOC_URI)
-    completions = pylsp_autoimport_completions(config, workspace, doc, com_position)
+    completions = pylsp_autoimport_completions(
+        config, workspace, doc, com_position, None
+    )
     workspace.rm_document(DOC_URI)
     assert not check_dict({"label": "List"}, completions)
 
 
-# This test has several large issues.
-# 1. autoimport relies on its sources being written to disk. This makes testing harder
-# 2. the hook doesn't handle removed files
-# 3. The testing framework cannot access the actual autoimport object so it cannot clear the cache
-# def test_autoimport_update_module(config: Config, workspace: Workspace):
-#     document2 = "SomethingYouShouldntWrite = 1"
-#     document = """SomethingYouShouldntWrit"""
-#     com_position = {
-#         "line": 0,
-#         "character": 3,
-#     }
-#     doc2_path = workspace.root_path + "/test_file_no_one_should_write_to.py"
-#     if os.path.exists(doc2_path):
-#         os.remove(doc2_path)
-#     DOC2_URI = uris.from_fs_path(doc2_path)
-#     workspace.put_document(DOC_URI, source=document)
-#     doc = workspace.get_document(DOC_URI)
-#     completions = pylsp_autoimport_completions(config, workspace, doc, com_position)
-#     assert len(completions) == 0
-#     with open(doc2_path, "w") as f:
-#         f.write(document2)
-#     workspace.put_document(DOC2_URI, source=document2)
-#     doc2 = workspace.get_document(DOC2_URI)
-#     pylsp_document_did_save(config, workspace, doc2)
-#     assert check_dict({"label": "SomethingYouShouldntWrite"}, completions)
-#     workspace.put_document(DOC2_URI, source="\n")
-#     doc2 = workspace.get_document(DOC2_URI)
-#     os.remove(doc2_path)
-#     pylsp_document_did_save(config, workspace, doc2)
-#     completions = pylsp_autoimport_completions(config, workspace, doc, com_position)
-#     assert len(completions) == 0
-#     workspace.rm_document(DOC_URI)
-
-
 class TestShouldInsert:
     def test_dot(self):
         assert not should_insert("""str.""", 4)
@@ -233,3 +225,105 @@ def test_get_names():
     """
     results = get_names(jedi.Script(code=source))
     assert results == set(["blah", "bleh", "e", "hello", "someone", "sfa", "a", "b"])
+
+
+# Tests ruff, flake8 and pyflakes messages
+@pytest.mark.parametrize(
+    "message",
+    ["Undefined name `os`", "F821 undefined name 'numpy'", "undefined name 'numpy'"],
+)
+def test_autoimport_code_actions_get_correct_module_name(autoimport_workspace, message):
+    source = "os.path.join('a', 'b')"
+    autoimport_workspace.put_document(DOC_URI, source=source)
+    doc = autoimport_workspace.get_document(DOC_URI)
+    diagnostic = {
+        "range": {
+            "start": {"line": 0, "character": 0},
+            "end": {"line": 0, "character": 2},
+        },
+        "message": message,
+    }
+    module_name = get_name_or_module(doc, diagnostic)
+    autoimport_workspace.rm_document(DOC_URI)
+    assert module_name == "os"
+
+
+# rope autoimport launches a sqlite database which checks from which thread it is called.
+# This makes the test below fail because we access the db from a different thread.
+# See https://stackoverflow.com/questions/48218065/objects-created-in-a-thread-can-only-be-used-in-that-same-thread
+# @pytest.mark.skipif(IS_WIN, reason="Flaky on Windows")
+# def test_autoimport_completions_for_notebook_document(
+#     client_server_pair,
+# ):
+#     client, server = client_server_pair
+#     send_initialize_request(client)
+
+#     with patch.object(server._endpoint, "notify") as mock_notify:
+#         # Expectations:
+#         # 1. We receive an autoimport suggestion for "os" in the first cell because
+#         #    os is imported after that.
+#         # 2. We don't receive an autoimport suggestion for "os" in the second cell because it's
+#         #    already imported in the second cell.
+#         # 3. We don't receive an autoimport suggestion for "os" in the third cell because it's
+#         #    already imported in the second cell.
+#         # 4. We receive an autoimport suggestion for "sys" because it's not already imported
+#         send_notebook_did_open(client, ["os", "import os\nos", "os", "sys"])
+#         wait_for_condition(lambda: mock_notify.call_count >= 3)
+
+#     server.m_workspace__did_change_configuration(
+#         settings={
+#             "pylsp": {
+#                 "plugins": {
+#                     "rope_autoimport": {
+#                         "memory": True,
+#                         "completions": {"enabled": True},
+#                     },
+#                 }
+#             }
+#         }
+#     )
+#     rope_autoimport_settings = server.workspace._config.plugin_settings(
+#         "rope_autoimport"
+#     )
+#     assert rope_autoimport_settings.get("completions", {}).get("enabled", False) is True
+#     assert rope_autoimport_settings.get("memory", False) is True
+
+#     # 1.
+#     suggestions = server.completions("cell_1_uri", {"line": 0, "character": 2}).get(
+#         "items"
+#     )
+#     assert any(
+#         suggestion
+#         for suggestion in suggestions
+#         if contains_autoimport(suggestion, "os")
+#     )
+
+#     # 2.
+#     suggestions = server.completions("cell_2_uri", {"line": 1, "character": 2}).get(
+#         "items"
+#     )
+#     assert not any(
+#         suggestion
+#         for suggestion in suggestions
+#         if contains_autoimport(suggestion, "os")
+#     )
+
+#     # 3.
+#     suggestions = server.completions("cell_3_uri", {"line": 0, "character": 2}).get(
+#         "items"
+#     )
+#     assert not any(
+#         suggestion
+#         for suggestion in suggestions
+#         if contains_autoimport(suggestion, "os")
+#     )
+
+#     # 4.
+#     suggestions = server.completions("cell_4_uri", {"line": 0, "character": 3}).get(
+#         "items"
+#     )
+#     assert any(
+#         suggestion
+#         for suggestion in suggestions
+#         if contains_autoimport(suggestion, "sys")
+#     )
