@@ -1,12 +1,16 @@
 # Copyright 2021- Python Language Server Contributors.
 
-import os
 import time
 from unittest.mock import patch, call
 
-from test.fixtures import CALL_TIMEOUT_IN_SECONDS
+from test.test_utils import (
+    CALL_TIMEOUT_IN_SECONDS,
+    send_initialize_request,
+    send_notebook_did_open,
+)
 
 import pytest
+from pylsp.workspace import Notebook
 
 from pylsp import IS_WIN
 from pylsp.lsp import NotebookCellKind
@@ -24,32 +28,18 @@ def wait_for_condition(condition, timeout=CALL_TIMEOUT_IN_SECONDS):
 @pytest.mark.skipif(IS_WIN, reason="Flaky on Windows")
 def test_initialize(client_server_pair):
     client, server = client_server_pair
-    response = client._endpoint.request(
-        "initialize",
-        {
-            "processId": 1234,
-            "rootPath": os.path.dirname(__file__),
-            "initializationOptions": {},
-        },
-    ).result(timeout=CALL_TIMEOUT_IN_SECONDS)
+    response = send_initialize_request(client)
     assert server.workspace is not None
     selector = response["capabilities"]["notebookDocumentSync"]["notebookSelector"]
     assert isinstance(selector, list)
 
 
 @pytest.mark.skipif(IS_WIN, reason="Flaky on Windows")
-def test_notebook_document__did_open(
-    client_server_pair,
-):
+def test_workspace_did_change_configuration(client_server_pair):
+    """Test that we can update a workspace config w/o error when a notebook is open."""
     client, server = client_server_pair
-    client._endpoint.request(
-        "initialize",
-        {
-            "processId": 1234,
-            "rootPath": os.path.dirname(__file__),
-            "initializationOptions": {},
-        },
-    ).result(timeout=CALL_TIMEOUT_IN_SECONDS)
+    send_initialize_request(client)
+    assert server.workspace is not None
 
     with patch.object(server._endpoint, "notify") as mock_notify:
         client._endpoint.notify(
@@ -63,54 +53,46 @@ def test_notebook_document__did_open(
                             "kind": NotebookCellKind.Code,
                             "document": "cell_1_uri",
                         },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_2_uri",
-                        },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_3_uri",
-                        },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_4_uri",
-                        },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_5_uri",
-                        },
                     ],
                 },
-                # Test as many edge cases as possible for the diagnostics message
                 "cellTextDocuments": [
                     {
                         "uri": "cell_1_uri",
                         "languageId": "python",
                         "text": "",
                     },
-                    {
-                        "uri": "cell_2_uri",
-                        "languageId": "python",
-                        "text": "\n",
-                    },
-                    {
-                        "uri": "cell_3_uri",
-                        "languageId": "python",
-                        "text": "\nimport sys\n\nabc\n\n",
-                    },
-                    {
-                        "uri": "cell_4_uri",
-                        "languageId": "python",
-                        "text": "x",
-                    },
-                    {
-                        "uri": "cell_5_uri",
-                        "languageId": "python",
-                        "text": "y\n",
-                    },
                 ],
             },
         )
+        wait_for_condition(lambda: mock_notify.call_count >= 1)
+    assert isinstance(server.workspace.get_document("notebook_uri"), Notebook)
+    assert len(server.workspace.documents) == 2
+
+    server.workspace.update_config(
+        {"pylsp": {"plugins": {"flake8": {"enabled": True}}}}
+    )
+
+    assert server.config.plugin_settings("flake8").get("enabled") is True
+    assert (
+        server.workspace.get_document("cell_1_uri")
+        ._config.plugin_settings("flake8")
+        .get("enabled")
+        is True
+    )
+
+
+@pytest.mark.skipif(IS_WIN, reason="Flaky on Windows")
+def test_notebook_document__did_open(
+    client_server_pair,
+):
+    client, server = client_server_pair
+    send_initialize_request(client)
+
+    with patch.object(server._endpoint, "notify") as mock_notify:
+        # Test as many edge cases as possible for the diagnostics messages
+        send_notebook_did_open(
+            client, ["", "\n", "\nimport sys\n\nabc\n\n", "x", "y\n"]
+        )
         wait_for_condition(lambda: mock_notify.call_count >= 5)
         expected_call_args = [
             call(
@@ -206,48 +188,11 @@ def test_notebook_document__did_change(
     client_server_pair,
 ):
     client, server = client_server_pair
-    client._endpoint.request(
-        "initialize",
-        {
-            "processId": 1234,
-            "rootPath": os.path.dirname(__file__),
-            "initializationOptions": {},
-        },
-    ).result(timeout=CALL_TIMEOUT_IN_SECONDS)
+    send_initialize_request(client)
 
     # Open notebook
     with patch.object(server._endpoint, "notify") as mock_notify:
-        client._endpoint.notify(
-            "notebookDocument/didOpen",
-            {
-                "notebookDocument": {
-                    "uri": "notebook_uri",
-                    "notebookType": "jupyter-notebook",
-                    "cells": [
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_1_uri",
-                        },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_2_uri",
-                        },
-                    ],
-                },
-                "cellTextDocuments": [
-                    {
-                        "uri": "cell_1_uri",
-                        "languageId": "python",
-                        "text": "import sys",
-                    },
-                    {
-                        "uri": "cell_2_uri",
-                        "languageId": "python",
-                        "text": "",
-                    },
-                ],
-            },
-        )
+        send_notebook_did_open(client, ["import sys", ""])
         wait_for_condition(lambda: mock_notify.call_count >= 2)
         assert len(server.workspace.documents) == 3
         for uri in ["cell_1_uri", "cell_2_uri", "notebook_uri"]:
@@ -478,48 +423,11 @@ def test_notebook__did_close(
     client_server_pair,
 ):
     client, server = client_server_pair
-    client._endpoint.request(
-        "initialize",
-        {
-            "processId": 1234,
-            "rootPath": os.path.dirname(__file__),
-            "initializationOptions": {},
-        },
-    ).result(timeout=CALL_TIMEOUT_IN_SECONDS)
+    send_initialize_request(client)
 
     # Open notebook
     with patch.object(server._endpoint, "notify") as mock_notify:
-        client._endpoint.notify(
-            "notebookDocument/didOpen",
-            {
-                "notebookDocument": {
-                    "uri": "notebook_uri",
-                    "notebookType": "jupyter-notebook",
-                    "cells": [
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_1_uri",
-                        },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_2_uri",
-                        },
-                    ],
-                },
-                "cellTextDocuments": [
-                    {
-                        "uri": "cell_1_uri",
-                        "languageId": "python",
-                        "text": "import sys",
-                    },
-                    {
-                        "uri": "cell_2_uri",
-                        "languageId": "python",
-                        "text": "",
-                    },
-                ],
-            },
-        )
+        send_notebook_did_open(client, ["import sys", ""])
         wait_for_condition(lambda: mock_notify.call_count >= 2)
         assert len(server.workspace.documents) == 3
         for uri in ["cell_1_uri", "cell_2_uri", "notebook_uri"]:
@@ -550,48 +458,11 @@ def test_notebook__did_close(
 @pytest.mark.skipif(IS_WIN, reason="Flaky on Windows")
 def test_notebook_definition(client_server_pair):
     client, server = client_server_pair
-    client._endpoint.request(
-        "initialize",
-        {
-            "processId": 1234,
-            "rootPath": os.path.dirname(__file__),
-            "initializationOptions": {},
-        },
-    ).result(timeout=CALL_TIMEOUT_IN_SECONDS)
+    send_initialize_request(client)
 
     # Open notebook
     with patch.object(server._endpoint, "notify") as mock_notify:
-        client._endpoint.notify(
-            "notebookDocument/didOpen",
-            {
-                "notebookDocument": {
-                    "uri": "notebook_uri",
-                    "notebookType": "jupyter-notebook",
-                    "cells": [
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_1_uri",
-                        },
-                        {
-                            "kind": NotebookCellKind.Code,
-                            "document": "cell_2_uri",
-                        },
-                    ],
-                },
-                "cellTextDocuments": [
-                    {
-                        "uri": "cell_1_uri",
-                        "languageId": "python",
-                        "text": "y=2\nx=1",
-                    },
-                    {
-                        "uri": "cell_2_uri",
-                        "languageId": "python",
-                        "text": "x",
-                    },
-                ],
-            },
-        )
+        send_notebook_did_open(client, ["y=2\nx=1", "x"])
         # wait for expected diagnostics messages
         wait_for_condition(lambda: mock_notify.call_count >= 2)
         assert len(server.workspace.documents) == 3
